.. toctree::
   :maxdepth: 2

.. _scripts:

Scripts Reference:
==================

.. _algorithm:

Algorithms
----------

bcdi_flatten_intensity.py
^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/algorithms/bcdi_flatten_intensity.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_blurring_function.py
^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/algorithms/bcdi_blurring_function.py
   :start-after: helptext
   :end-before: """
   :language: rst

Experiment
----------

bcdi_ccd_calib.py
^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/experiment/bcdi_ccd_calib.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_ccd_calib_cristal.py
^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/experiment/bcdi_ccd_calib_cristal.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_ccd_calib_sixs.py
^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/experiment/bcdi_ccd_calib_sixs.py
   :start-after: helptext
   :end-before: """
   :language: rst

.. _graph:

Graph
-----

bcdi_3D_object_movie.py
^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/graph/bcdi_3D_object_movie.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_linecut_diffpattern.py
^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/graph/bcdi_linecut_diffpattern.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_scan_analysis.py
^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/graph/bcdi_scan_analysis.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_scan_movie.py
^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/graph/bcdi_scan_movie.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_view_mesh.py
^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/graph/bcdi_view_mesh.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_view_psf.py
^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/graph/bcdi_view_psf.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_visu_2D_slice.py
^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/graph/bcdi_visu_2D_slice.py
   :start-after: helptext
   :end-before: """
   :language: rst

.. _preprocess:

Preprocessing
-------------

bcdi_apodize.py
^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/preprocessing/bcdi_apodize.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_concatenate_scans.py
^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/preprocessing/bcdi_concatenate_scans.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_interpolate_CDI.py
^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/preprocessing/bcdi_interpolate_CDI.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_preprocess_BCDI.py
^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/preprocessing/bcdi_preprocess_BCDI.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_preprocess_CDI.py
^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/preprocessing/bcdi_preprocess_CDI.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_read_BCDI_scan.py
^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/preprocessing/bcdi_read_BCDI_scan.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_read_edf.py
^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/preprocessing/bcdi_read_edf.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_read_data_P10.py
^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/preprocessing/bcdi_read_data_P10.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_rescale_support.py
^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/preprocessing/bcdi_rescale_support.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_rotate_scan.py
^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/preprocessing/bcdi_rotate_scan.py
   :start-after: helptext
   :end-before: """
   :language: rst

.. _postprocess:

Postprocessing
--------------


bcdi_amp_histogram.py
^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/postprocessing/bcdi_amp_histogram.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_angular_profile.py
^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/postprocessing/bcdi_angular_profile.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_bulk_surface_strain.py
^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/postprocessing/bcdi_bulk_surface_strain.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_compare_BCDI_SEM.py
^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/postprocessing/bcdi_compare_BCDI_SEM.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_correct_angles_detector.py
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/postprocessing/bcdi_correct_angles_detector.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_facet_strain.py
^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/postprocessing/bcdi_facet_strain.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_line_profile.py
^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/postprocessing/bcdi_line_profile.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_modes_decomposition.py
^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/postprocessing/bcdi_modes_decomposition.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_polarplot.py
^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/postprocessing/bcdi_polarplot.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_post_process_BCDI_2D.py
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/postprocessing/bcdi_post_process_BCDI_2D.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_prtf_BCDI.py
^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/postprocessing/bcdi_prtf_BCDI.py
   :start-after: helptext
   :end-before: """
   :language: rst
   
bcdi_prtf_BCDI_2D.py
^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/postprocessing/bcdi_prtf_BCDI_2D.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_prtf_CDI.py
^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/postprocessing/bcdi_prtf_CDI.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_rocking_curves.py
^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/postprocessing/bcdi_rocking_curves.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_strain.py
^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/postprocessing/bcdi_strain.py
   :start-after: helptext
   :end-before: """
   :language: rst


bcdi_strain_mean_var_rms.py
^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/postprocessing/bcdi_strain_mean_var_rms.py
   :start-after: helptext
   :end-before: """
   :language: rst
   
bcdi_volume_phasing.py
^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/postprocessing/bcdi_volume_phasing.py
   :start-after: helptext
   :end-before: """
   :language: rst

.. _publi:

Publication
-----------

bcdi_coefficient_variation.py
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/publication/bcdi_coefficient_variation.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_compa_simu_exp.py
^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/publication/bcdi_compa_simu_exp.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_diffpattern_from_reconstruction.py
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/publication/bcdi_diffpattern_from_reconstruction.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_plot_diffpattern_2D.py
^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/publication/bcdi_plot_diffpattern_2D.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_plot_strain.py
^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/publication/bcdi_plot_strain.py
   :start-after: helptext
   :end-before: """
   :language: rst

.. _simulation:

Simulation
----------

bcdi_diffraction_angles.py
^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/simulation/bcdi_diffraction_angles.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_domain_orientation.py
^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/simulation/bcdi_domain_orientation.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_kinematic_sum_forloop.py
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/simulation/bcdi_kinematic_sum_forloop.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_plane_angle.py
^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/simulation/bcdi_plane_angle.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_simu_diffpattern_BCDI.py
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/simulation/bcdi_simu_diffpattern_BCDI.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_simu_diffpattern_CDI.py
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/simulation/bcdi_simu_diffpattern_CDI.py
   :start-after: helptext
   :end-before: """
   :language: rst
   
bcdi_simu_signe_phase.py
^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/simulation/bcdi_simu_signe_phase.py
   :start-after: helptext
   :end-before: """
   :language: rst

.. _utils:

Utilities
---------

bcdi_angular_avg_3Dto1D.py
^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/utils/bcdi_angular_avg_3Dto1D.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_calibration_grid_SEM.py
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/utils/bcdi_calibration_grid_SEM.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_center_of_rotation.py
^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/utils/bcdi_center_of_rotation.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_correlation_realspace.py
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/utils/bcdi_correlation_realspace.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_crop_npz.py
^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/utils/bcdi_crop_npz.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_cross_corr_fast_live.py
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/utils/bcdi_cross_corr_fast_live.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_fit_1D_curve.py
^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/utils/bcdi_fit_1D_curve.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_fit_1D_background.py
^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/utils/bcdi_fit_1D_background.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_parse_fio2spec.py
^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/utils/bcdi_parse_fio2spec.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_primes.py
^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/utils/bcdi_primes.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_save_to_mat.py
^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/utils/bcdi_save_to_mat.py
   :start-after: helptext
   :end-before: """
   :language: rst

.. _xcca:

XCCA
----

bcdi_view_ccf.py
^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/xcca/bcdi_view_ccf.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_view_ccf_map.py
^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/xcca/bcdi_view_ccf_map.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_xcca_3D_map_polar.py
^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/xcca/bcdi_xcca_3D_map_polar.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_xcca_3D_map_rect.py
^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/xcca/bcdi_xcca_3D_map_rect.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_xcca_3D_polar.py
^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/xcca/bcdi_xcca_3D_polar.py
   :start-after: helptext
   :end-before: """
   :language: rst

bcdi_xcca_3D_rect.py
^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../scripts/xcca/bcdi_xcca_3D_rect.py
   :start-after: helptext
   :end-before: """
   :language: rst

